betty.about module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.about module

Provide information about (this version of) Betty.

betty.about.is_development() → bool

  Check if the current Betty installation is an unstable development version.

betty.about.is_stable() → bool

  Check if the current Betty installation is a stable version.

betty.about.report() → str

  Produce a human-readable report about the current Betty installation.

  Returns:

    A human-readable string in US English, using monospace indentation.

betty.about.version() → str

  Get the current Betty installation’s version, if it has any.

betty.about.version_label() → str

  Get the human-readable label for the current Betty installation’s version.